<?php

$LANG = array(

# install.php
'L_INSTALL_TITLE'					=> 'Installatie',
'L_WRONG_PHP_VERSION'				=> 'PluXml heeft PHP-versie 5 of hoger nodig om goed te functioneren.',
'L_SELECT_LANG'						=> 'Kies uw taal',
'L_INPUT_CHANGE'					=> 'Verander',
'L_DEFAULT_CATEGORY_TITLE'			=> 'Rubriek 1',
'L_DEFAULT_CATEGORY_URL'			=> 'rubriek-1',
'L_DEFAULT_STATIC_TITLE'			=> 'Statisch 1',
'L_DEFAULT_STATIC_URL'				=> 'statisch-1',
'L_DEFAULT_ARTICLE_TITLE'			=> 'Eerste artikel',
'L_DEFAULT_ARTICLE_URL'				=> 'eerste-artikel',
'L_DEFAULT_COMMENT_CONTENT'			=> 'Dit is een eerste commentaar !',
'L_ERR_PLUXML_ALREADY_INSTALLED'	=> 'PluXml is al geconfigureerd !',
'L_ERR_MISSING_USER'				=> 'Vul de naam van de redacteur in !',
'L_ERR_MISSING_LOGIN'				=> 'Vul een loginnaam in !',
'L_ERR_MISSING_PASSWORD'			=> 'Vul een wachtwoord in !',
'L_ERR_PASSWORD_CONFIRMATION'		=> 'Bevestiging van wachtwoord mislukt !',
'L_PLUXML_INSTALLATION'				=> 'Installatie van PluXml',
'L_SITE_DESCRIPTION'				=> 'Blog of Cms in XML !',
'L_VERSION'							=> 'versie',
'L_USERNAME'						=> 'Naam van de beheerder',
'L_LOGIN'							=> 'Login van de beheerder',
'L_PASSWORD'						=> 'Wachtwoord',
'L_PASSWORD_CONFIRMATION'			=> 'Bevestig het wachtwoord',
'L_INPUT_INSTALL'					=> 'Installeer',
'L_TIMEZONE'						=> 'Tijdzone',
'L_PWD_VERY_WEAK'					=> 'Zeer zwak wachtwoord',
'L_PWD_WEAK'						=> 'Zwak wachtwoord',
'L_PWD_GOOD'						=> 'Goed wachtwoord',
'L_PWD_STRONG'						=> 'Sterk wachtwoord',
);
?>